buildingspy — BuildingsPy documentation

# buildingspy

buildingspy is a Python package that can be used to:

> - Run Modelica simulations using OPTIMICA or Dymola.

> - Process `*.mat` output files that were generated by OPTIMICA, Dymola or OpenModelica.

> - Run unit tests as part of the library development.

> - Refactor Modelica libraries.

> - Merge the IBPSA library to other Modelica libraries.

The package provides functions to extract data series from the output file for further use in the python packages matplotlib for plotting and SciPy for scientific computing.

Contents:

- Install and Uninstall BuildingsPy
- Running simulations
- Dymola
- Optimica
- Reading output files, plotting results and reporting simulation output
  - File reader
  - Plotter
  - Reporter
- FMI
- Examples
  - Simulating a model with two different parameter values
  - Plotting of Time Series
- Development
  - Refactoring code
  - Regression tests
  - Validator of syntax
  - Merging Modelica IBPSA Library
  - Error dictionary
- Copyright and License
- Acknowledgments
- Revisions
  - BuildingsPy Changelog

# Indices and tables

- Index

- Module Index

- Search Page